//import Serial communication library
import processing.serial.*;

//init variables
Serial commPort;
int state;
float tempF;
int yDist;
PFont font12;
PFont font24;
int numReadings = 190;
int[] stateHistory = new int[numReadings];

void setup()
{
  //setup fonts for use throughout the application
  font12 = loadFont("Verdana-12.vlw"); 
  
  //set the size of the window
  size(300, 200);
  
  //init serial communication port
  String portName = Serial.list()[0];
  commPort = new Serial(this, portName, 9600);
  
  //fill History with default readings
  for(int i = 0; i<numReadings; i++)
    stateHistory[i] = 0;
}

void draw()
{
  //get the state from the serial port
  while (commPort.available() > 0) 
  {
    state = commPort.read();
  
    //refresh the background to clear old data
    background(123);

    //draw the temp rectangle
    colorMode(RGB, 160);  //use color mode sized for fading
    stroke (0);
    rect (49,19,22,162);
    //fade red and blue within the rectangle
    for (int colorIndex = 0; colorIndex <= 160; colorIndex++) 
    {
      stroke(colorIndex,160 - colorIndex, 0);
      line(50, 20+colorIndex, 70, 20+colorIndex);
    }
    
    //draw graph
    stroke(0);
    fill(255,255,255);

    rect(90,20,190,160);
    for (int i = 0; i<numReadings-1; i++) {  
         stateHistory[i] = stateHistory[i + 1];
         point(90 + i, 170 - stateHistory[i]*0.5); 
    }
    stateHistory[numReadings-1] = state;
    point(90 + numReadings, 170 - stateHistory[numReadings-1]*0.5); 
    
  
    //write reference values
    fill(0,0,0);
    textFont(font12); 
    textAlign(LEFT,TOP);
    text(str(state),5,5);
    textAlign(RIGHT,TOP);
    text("HIGH", 45, 20); 
    textAlign(RIGHT,BOTTOM);
    text("LOW", 45, 180);
  
    //draw triangle pointer
    yDist = int(150 - state * 0.5);
    stroke(0);
    triangle(85, 20+yDist, 75, 15+yDist, 75, 25+yDist);
    saveFrame("PB-######.png");
    
  
  }
}


